@@ -4,9 +4,10 @@
 pub use bytes::Bytes;
 
 pub mod args;
+pub mod block;
 pub mod env;
 pub mod feature;
-pub mod locale;
+pub mod i18n;
 pub mod output;
 pub mod prelude;
 pub mod skill;
